/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-central-linux-xulrunner/build/dom/indexedDB/nsIIndexedDatabaseManager.idl
 */

#ifndef __gen_nsIIndexedDatabaseManager_h__
#define __gen_nsIIndexedDatabaseManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */


/* starting interface:    nsIIndexedDatabaseManager */
#define NS_IINDEXEDDATABASEMANAGER_IID_STR "dba13d2e-ea4f-4011-9b66-a8b0e61a7f84"

#define NS_IINDEXEDDATABASEMANAGER_IID \
  {0xdba13d2e, 0xea4f, 0x4011, \
    { 0x9b, 0x66, 0xa8, 0xb0, 0xe6, 0x1a, 0x7f, 0x84 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIIndexedDatabaseManager : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IINDEXEDDATABASEMANAGER_IID)

  /* unsigned long long getUsageForURI (in nsIURI aURI); */
  NS_SCRIPTABLE NS_IMETHOD GetUsageForURI(nsIURI *aURI, PRUint64 *_retval NS_OUTPARAM) = 0;

  /* void clearDatabasesForURI (in nsIURI aURI); */
  NS_SCRIPTABLE NS_IMETHOD ClearDatabasesForURI(nsIURI *aURI) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIndexedDatabaseManager, NS_IINDEXEDDATABASEMANAGER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIINDEXEDDATABASEMANAGER \
  NS_SCRIPTABLE NS_IMETHOD GetUsageForURI(nsIURI *aURI, PRUint64 *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD ClearDatabasesForURI(nsIURI *aURI); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIINDEXEDDATABASEMANAGER(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetUsageForURI(nsIURI *aURI, PRUint64 *_retval NS_OUTPARAM) { return _to GetUsageForURI(aURI, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD ClearDatabasesForURI(nsIURI *aURI) { return _to ClearDatabasesForURI(aURI); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIINDEXEDDATABASEMANAGER(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetUsageForURI(nsIURI *aURI, PRUint64 *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUsageForURI(aURI, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD ClearDatabasesForURI(nsIURI *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearDatabasesForURI(aURI); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIndexedDatabaseManager : public nsIIndexedDatabaseManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIINDEXEDDATABASEMANAGER

  nsIndexedDatabaseManager();

private:
  ~nsIndexedDatabaseManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIndexedDatabaseManager, nsIIndexedDatabaseManager)

nsIndexedDatabaseManager::nsIndexedDatabaseManager()
{
  /* member initializers and constructor code */
}

nsIndexedDatabaseManager::~nsIndexedDatabaseManager()
{
  /* destructor code */
}

/* unsigned long long getUsageForURI (in nsIURI aURI); */
NS_IMETHODIMP nsIndexedDatabaseManager::GetUsageForURI(nsIURI *aURI, PRUint64 *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearDatabasesForURI (in nsIURI aURI); */
NS_IMETHODIMP nsIndexedDatabaseManager::ClearDatabasesForURI(nsIURI *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIndexedDatabaseManager_h__ */
